import Image from "next/image";

import { ContentLines } from "@/components/shared/content-lines";
import { FAQItem } from "@/components/shared/faq-item";
import BlurFade from "@/components/ui/blur-fade";
import { Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";
import { getFAQData } from "@/utils/get-fake-data";

interface FAQsProps {
	locale: Locale;
}

export default async function FAQSServices({ locale }: FAQsProps) {
	const data = await getFAQData();

	return (
		<section className="mb-20 mt-32 flex flex-col-reverse gap-8 lg:flex-row">
			{/* Image Column */}
			<BlurFade direction="left" delay={0.25} inView>
				<Image
					src={"/faqs.jpg"}
					alt=""
					width={510}
					height={556}
					className="flex-[50%] bg-red-400 object-cover"
					priority
					style={{ width: "510px", height: "556px", borderRadius: "10px" }}
				/>
			</BlurFade>

			{/* Content Column */}
			<BlurFade
				direction="right"
				delay={0.25}
				inView
				className={cn("flex-[50%]")}
			>
				<div className="mb-8">
					<ContentLines
						title={data.section.subtitle?.[locale]}
						underlineColor="custom-primary-accent"
						textColor="text-custom-primary-accent"
						padding="none"
					/>
					<h2 className="mt-4 text-[30px] font-normal text-[#202020]">
						{data.section.title?.[locale]}
					</h2>
				</div>

				<div className="mt-8 space-y-4">
					{data.items?.map((item) => (
						<FAQItem
							key={item.id}
							question={item.question?.[locale]}
							answer={item.answer[locale]}
							isRTL={locale === "ar"}
						/>
					))}
				</div>
			</BlurFade>
		</section>
	);
}
